.. _glossary:

========
Glossary
========

.. glossary::

    CJK
        1. In computer software, `internationalization`_ of *Chinese, Japanese,
           and Korean* language.
        2. In cihai, specifically, character information from Chinese,
           Japanese and Korean languages. Such as definitions, dictionary
           index references, phonetics, character decompositions and
           stroke information (order and amount).

    UNIHAN
        A character database of CJK information provided by the Unicode
        Consortium. See the documentation as http://www.unicode.org/reports/tr38/.

    cjklib
        A popular CJK library in python created by Christoph Burgmer

    cihai
        1. A CJK library in python built from the ground up under a
           permissive license and modern python development practices
        2. A workgroup for finding, digitizing, and preserving CJK
           dataasets

    SQLAlchemy
        A relational database library used to store and retrieve character
        information in cihai

    Data Packages
        A standard for storing data, see
        http://frictionlessdata.io/data-packages/

    XDG Base Directory
        A specification for directory locations designed to work across
        platforms. See https://specifications.freedesktop.org/basedir-spec/basedir-spec-0.6.html.

.. _internationalization: https://en.wikipedia.org/wiki/Internationalization_and_localization
